@@ -1,4 +1,4 @@
-local S = homedecor_i18n.gettext
+local S = minetest.get_translator("building_blocks")
 
 minetest.register_craftitem("building_blocks:sticks", {
 	description = S("Small bundle of sticks"),
@@ -20,4 +20,4 @@ minetest.register_tool("building_blocks:knife", {
 			fleshy={times={[2]=5.50, [3]=2.80}, uses=100, maxlevel=1}
 		}
 	},
-})
\ No newline at end of file
+})
